StochasticLocalSearchIF

Trait StochasticLocalSearchIF 

pub trait StochasticLocalSearchIF {
    // Required method
    fn stochastic_local_search(
        &mut self,
        asg: &impl AssignIF,
        start: &mut HashMap<VarId, bool>,
        limit: usize,
    ) -> (usize, usize);
}

Required Methods

returns the decision level of the given assignment and the one of the final assignment. Note: the lower level a set of clauses make a conflict at, the higher learning rate a solver can keep and the better learnt clauses we will have. This would be a better criteria that can be used in CDCL solvers.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors